@@ -1,10 +1,7 @@
-#ifndef PARTITIONS_COUNT_REP_H
-#define PARTITIONS_COUNT_REP_H
+#pragma once
 
 double CountPartsRepLenCap(int n, int m, int cap, int strtLen);
 double CountPartsRepLen(int n, int m, int cap, int strtLen);
 double CountPartsRep(int n, int m, int cap, int strtLen);
 double CountCompsRepLen(int n, int m, int cap, int strtLen);
 double CountCompsRepZero(int n, int m, int cap, int strtLen);
-
-#endif
